@@ -74,13 +74,12 @@
     #else
         #error Only MSC and mingw supported for Windows
     #endif
-    #ifndef __MINGW32__
-        #define size_t     __int64
-    #endif
     #ifndef UINT64_MAX
         #define UINT64_MAX ((uint64_t)0xffffffffffffffff)
     #endif
-    #define PRIx64 "I64x"
+    #ifndef PRIx64
+        #define PRIx64 "I64x"
+    #endif
     int __cdecl _fseeki64(FILE *, __int64, int);
     __int64 __cdecl _ftelli64(FILE *);
 
@@ -97,7 +96,7 @@
     #ifdef __DJGPP__
         #define gmtime_r(tp,tmp) (gmtime(tp)?(*(tmp)=*gmtime(tp),(tmp)):0)
         #define ctime_r(tp,tmp) (ctime(tp)?(strcpy((tmp),ctime((tp))),(tmp)):0)
-		#define fseeko(stream, offset, whence) fseek(stream, (long)offset, whence)
+        #define fseeko(stream, offset, whence) fseek(stream, (long)offset, whence)
         #define ftello ftell
     #endif
     #ifdef HAVE_UNISTD_H
@@ -135,20 +134,23 @@
 
 void  pst_debug_lock();
 void  pst_debug_unlock();
+void  pst_debug_setlevel(int level);
 void  pst_debug_init(const char* fname, void* output_mutex);
-void  pst_debug_func(const char* function);
-void  pst_debug_func_ret();
-void  pst_debug(int line, const char *file, const char *fmt, ...);
-void  pst_debug_hexdump(int line, const char *file, const char* buf, size_t size, int cols, int delta);
+void  pst_debug_func(int level, const char* function);
+void  pst_debug_func_ret(int level);
+void  pst_debug(int level, int line, const char *file, const char *fmt, ...);
+void  pst_debug_hexdump(int level, int line, const char *file, const char* buf, size_t size, int cols, int delta);
 void  pst_debug_hexdumper(FILE* out, const char* buf, size_t size, int cols, int delta);
-void  pst_debug_close(void);
+void  pst_debug_close();
 void* pst_malloc(size_t size);
 void *pst_realloc(void *ptr, size_t size);
 
-#define MESSAGEPRINT(...) pst_debug(__LINE__, __FILE__,  __VA_ARGS__)
+#define MESSAGEPRINT1(...) pst_debug(1, __LINE__, __FILE__,  __VA_ARGS__)
+#define MESSAGEPRINT2(...) pst_debug(2, __LINE__, __FILE__,  __VA_ARGS__)
+#define MESSAGEPRINT3(...) pst_debug(3, __LINE__, __FILE__,  __VA_ARGS__)
 
 #define WARN(x) {           \
-    MESSAGEPRINT x;         \
+    MESSAGEPRINT3 x;        \
     pst_debug_lock();       \
         printf x;           \
         fflush(stdout);     \
@@ -160,21 +162,21 @@ void *pst_realloc(void *ptr, size_t size);
     exit(EXIT_FAILURE);     \
 }
 
-#define DEBUG_WARN(x)           MESSAGEPRINT x
-#define DEBUG_INFO(x)           MESSAGEPRINT x
-#define DEBUG_HEXDUMP(x, s)     pst_debug_hexdump(__LINE__, __FILE__, (char*)x, s, 0x10, 0)
-#define DEBUG_HEXDUMPC(x, s, c) pst_debug_hexdump(__LINE__, __FILE__, (char*)x, s, c, 0)
+#define DEBUG_WARN(x)           MESSAGEPRINT3 x
+#define DEBUG_INFO(x)           MESSAGEPRINT2 x
+#define DEBUG_HEXDUMP(x, s)     pst_debug_hexdump(1, __LINE__, __FILE__, (char*)x, s, 0x10, 0)
+#define DEBUG_HEXDUMPC(x, s, c) pst_debug_hexdump(1, __LINE__, __FILE__, (char*)x, s, c, 0)
 
 
 #define DEBUG_ENT(x)                                            \
     {                                                           \
-        pst_debug_func(x);                                      \
-        pst_debug(__LINE__, __FILE__, "Entering function\n");   \
+      pst_debug_func(1, x);                                      \
+      pst_debug(1, __LINE__, __FILE__, "Entering function\n");   \
     }
 #define DEBUG_RET()                                             \
     {                                                           \
-        pst_debug(__LINE__, __FILE__, "Leaving function\n");    \
-        pst_debug_func_ret();                                   \
+      pst_debug(1, __LINE__, __FILE__, "Leaving function\n");    \
+      pst_debug_func_ret(1);                     \
     }
 
 #define DEBUG_INIT(fname,mutex) {pst_debug_init(fname,mutex);}
@@ -242,11 +244,11 @@ void *pst_realloc(void *ptr, size_t size);
                   (((uint8_t const *)(p))[2] << 16) |    \
                   (((uint8_t const *)(p))[3] << 24))
 
-#define PST_LE_GET_UINT16(p)				  \
+#define PST_LE_GET_UINT16(p)                  \
         (uint16_t)((((uint8_t const *)(p))[0] << 0)  |    \
                    (((uint8_t const *)(p))[1] << 8))
 
-#define PST_LE_GET_INT16(p)				  \
+#define PST_LE_GET_INT16(p)               \
         (int16_t)((((uint8_t const *)(p))[0] << 0)  |    \
                    (((uint8_t const *)(p))[1] << 8))
 
@@ -254,5 +256,6 @@ void *pst_realloc(void *ptr, size_t size);
 
 #define PST_LE_GET_INT8(p) (*(int8_t const *)(p))
 
+#define MAXDATEFMTLEN 40
 
 #endif //DEFINEH_H
